==> estateplat-common-1.2.4-20181227.092346-78-sources.jar: cn/gtmap/estateplat/model/etl/Sqxx.java <==
package cn.gtmap.estateplat.model.etl;

import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018/8/29
 * @description 外网申报登记申请信息模型
 */
public class Sqxx implements Serializable {
    private String sqid;//申请ID
    private String wwslbh;//外网受理编号
    private String djlx; //登记类型;字典项
    private String djlxmc;//登记类型;名称
    private String sqdjlx;//申请登记类型;字典项
    private String sqdjlxmc;//申请登记类型:名称
    private String qllx;//权利类型;字典项
    private String qllxmc;//权利类型;名称
    private String gyfs;//共有方式;字典项
    private String gyfsmc;//共有方式;名称
    private String sffbcz;//是否分别持证;字典项
    private String zl;//坐落
    private String bdcdyh; //不动产单元号
    private String ybdcqzh;//原不动产权证证号
    private String yfczh;//原房产证号
    private String ytdzh;//原土地证号
    private String ybdcywh;//原不动产业务号
    private String yfcywh;//原房产业务号
    private String ytdywh;//原土地业务号
    private Double bdbzzqse; //被担保主债权数额
    private String zgzqqdss;//最高债权确定事实
    private Double zgzqqdse;//最高债权确定数额
    private Date zwlxqxksrq;//债务履行期限开始日期
    private Date zwlxqxjsrq;//债务履行期限结束日期
    private Double pgjz;//评估价值
    private String dyfw;//抵押范围
    private String dyfs;//抵押方式
    private String dysw;//抵押顺位
    private String dkfs;//贷款方式
    private String sfaj;//是否按揭
    private String fj;//附记
    private String cjyh;//创建用户
    private Date cjsj;//创建日期
    private Double jzmj;//建筑面积
    private Double tnjzmj;//套内建筑面积
    private Double ftjzmj;//分摊建筑面积
    private String zdzhyt;//宗地宗海用途
    private Integer fwlx;//房屋类型
    private String fwxz;//房屋性质
    private Double dytdmj;//独用土地面积
    private String fwjg;//房屋结构
    private Double fttdmj;//分摊土地面积
    private String ghyt;//规划用途
    private Integer szc;//所在层
    private String szmyc;//所在名义层
    private Integer zcs;//总层数
    private Date tdsyksqx;//土地使用开始期限
    private Date tdsyjsqx;//土地使用结束期限
    private String zdzhqlxz;//宗地总海权利性质
    private String djzx;//登记子项
    private String djyy;//登记原因
    private Double fdcjyjg;//房地产交易价格
    private String bz;//备注
    private String lzr;//领证人
    private String lzrzjzl;//领证人证件种类
    private String lzrzjh;//领证人证件号
    private String lzrlxdh;//领证人联系电话
    public String getSqid() {
        return sqid;
    }

    public void setSqid(String sqid) {
        this.sqid = sqid;
    }

    public String getWwslbh() {
        return wwslbh;
    }

    public void setWwslbh(String wwslbh) {
        this.wwslbh = wwslbh;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjlxmc() {
        return djlxmc;
    }

    public void setDjlxmc(String djlxmc) {
        this.djlxmc = djlxmc;
    }

    public String getSqdjlx() {
        return sqdjlx;
    }

    public void setSqdjlx(String sqdjlx) {
        this.sqdjlx = sqdjlx;
    }

    public String getSqdjlxmc() {
        return sqdjlxmc;
    }

    public void setSqdjlxmc(String sqdjlxmc) {
        this.sqdjlxmc = sqdjlxmc;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQllxmc() {
        return qllxmc;
    }

    public void setQllxmc(String qllxmc) {
        this.qllxmc = qllxmc;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getGyfsmc() {
        return gyfsmc;
    }

    public void setGyfsmc(String gyfsmc) {
        this.gyfsmc = gyfsmc;
    }

    public String getSffbcz() {
        return sffbcz;
    }

    public void setSffbcz(String sffbcz) {
        this.sffbcz = sffbcz;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYbdcqzh() {
        return ybdcqzh;
    }

    public void setYbdcqzh(String ybdcqzh) {
        this.ybdcqzh = ybdcqzh;
    }

    public String getYfczh() {
        return yfczh;
    }

    public void setYfczh(String yfczh) {
        this.yfczh = yfczh;
    }

    public String getYtdzh() {
        return ytdzh;
    }

    public void setYtdzh(String ytdzh) {
        this.ytdzh = ytdzh;
    }

    public String getYbdcywh() {
        return ybdcywh;
    }

    public void setYbdcywh(String ybdcywh) {
        this.ybdcywh = ybdcywh;
    }

    public String getYfcywh() {
        return yfcywh;
    }

    public void setYfcywh(String yfcywh) {
        this.yfcywh = yfcywh;
    }

    public String getYtdywh() {
        return ytdywh;
    }

    public void setYtdywh(String ytdywh) {
        this.ytdywh = ytdywh;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public Double getZgzqqdse() {
        return zgzqqdse;
    }

    public void setZgzqqdse(Double zgzqqdse) {
        this.zgzqqdse = zgzqqdse;
    }

    public Date getZwlxqxksrq() {
        return zwlxqxksrq;
    }

    public void setZwlxqxksrq(Date zwlxqxksrq) {
        this.zwlxqxksrq = zwlxqxksrq;
    }

    public Date getZwlxqxjsrq() {
        return zwlxqxjsrq;
    }

    public void setZwlxqxjsrq(Date zwlxqxjsrq) {
        this.zwlxqxjsrq = zwlxqxjsrq;
    }

    public Double getPgjz() {
        return pgjz;
    }

    public void setPgjz(Double pgjz) {
        this.pgjz = pgjz;
    }

    public String getDyfw() {
        return dyfw;
    }

    public void setDyfw(String dyfw) {
        this.dyfw = dyfw;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getDysw() {
        return dysw;
    }

    public void setDysw(String dysw) {
        this.dysw = dysw;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public String getSfaj() {
        return sfaj;
    }

    public void setSfaj(String sfaj) {
        this.sfaj = sfaj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getCjyh() {
        return cjyh;
    }

    public void setCjyh(String cjyh) {
        this.cjyh = cjyh;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public String getZdzhyt() {
        return zdzhyt;
    }

    public void setZdzhyt(String zdzhyt) {
        this.zdzhyt = zdzhyt;
    }

    public Integer getFwlx() {
        return fwlx;
    }

    public void setFwlx(Integer fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public String getSzmyc() {
        return szmyc;
    }

    public void setSzmyc(String szmyc) {
        this.szmyc = szmyc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Date getTdsyksqx() {
        return tdsyksqx;
    }

    public void setTdsyksqx(Date tdsyksqx) {
        this.tdsyksqx = tdsyksqx;
    }

    public Date getTdsyjsqx() {
        return tdsyjsqx;
    }

    public void setTdsyjsqx(Date tdsyjsqx) {
        this.tdsyjsqx = tdsyjsqx;
    }

    public String getZdzhqlxz() {
        return zdzhqlxz;
    }

    public void setZdzhqlxz(String zdzhqlxz) {
        this.zdzhqlxz = zdzhqlxz;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public Double getFdcjyjg() {
        return fdcjyjg;
    }

    public void setFdcjyjg(Double fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getLzr() {
        return lzr;
    }

    public void setLzr(String lzr) {
        this.lzr = lzr;
    }

    public String getLzrzjzl() {
        return lzrzjzl;
    }

    public void setLzrzjzl(String lzrzjzl) {
        this.lzrzjzl = lzrzjzl;
    }

    public String getLzrzjh() {
        return lzrzjh;
    }

    public void setLzrzjh(String lzrzjh) {
        this.lzrzjh = lzrzjh;
    }

    public String getLzrlxdh() {
        return lzrlxdh;
    }

    public void setLzrlxdh(String lzrlxdh) {
        this.lzrlxdh = lzrlxdh;
    }
}

==> estateplat-common-1.2.4-20200915.015441-436-sources.jar: cn/gtmap/estateplat/model/etl/Sqxx.java <==
package cn.gtmap.estateplat.model.etl;

import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018/8/29
 * @description 外网申报登记申请信息模型
 */
public class Sqxx implements Serializable {
    private String sqid;//申请ID
    private String wwslbh;//外网受理编号
    private String djlx; //登记类型;字典项
    private String djlxmc;//登记类型;名称
    private String sqdjlx;//申请登记类型;字典项
    private String sqdjlxmc;//申请登记类型:名称
    private String qllx;//权利类型;字典项
    private String qllxmc;//权利类型;名称
    private String gyfs;//共有方式;字典项
    private String gyfsmc;//共有方式;名称
    private String sffbcz;//是否分别持证;字典项
    private String zl;//坐落
    private String bdcdyh; //不动产单元号
    private String ybdcqzh;//原不动产权证证号
    private String yfczh;//原房产证号
    private String ytdzh;//原土地证号
    private String ybdcywh;//原不动产业务号
    private String yfcywh;//原房产业务号
    private String ytdywh;//原土地业务号
    private Double bdbzzqse; //被担保主债权数额
    private String zgzqqdss;//最高债权确定事实
    private Double zgzqqdse;//最高债权确定数额
    private Date zwlxqxksrq;//债务履行期限开始日期
    private Date zwlxqxjsrq;//债务履行期限结束日期
    private Double pgjz;//评估价值
    private String dyfw;//抵押范围
    private String dyfs;//抵押方式
    private String dysw;//抵押顺位
    private String dkfs;//贷款方式
    private String sfaj;//是否按揭
    private String fj;//附记
    private String cjyh;//创建用户
    private Date cjsj;//创建日期
    private Double jzmj;//建筑面积
    private Double tnjzmj;//套内建筑面积
    private Double ftjzmj;//分摊建筑面积
    private String zdzhyt;//宗地宗海用途
    private Integer fwlx;//房屋类型
    private String fwxz;//房屋性质
    private Double dytdmj;//独用土地面积
    private String fwjg;//房屋结构
    private Double fttdmj;//分摊土地面积
    private String ghyt;//规划用途
    private Integer szc;//所在层
    private String szmyc;//所在名义层
    private Integer zcs;//总层数
    private Date tdsyksqx;//土地使用开始期限
    private Date tdsyjsqx;//土地使用结束期限
    private String zdzhqlxz;//宗地总海权利性质
    private String djzx;//登记子项
    private String djyy;//登记原因
    private Double fdcjyjg;//房地产交易价格
    private String bz;//备注
    private String lzr;//领证人
    private String lzrzjzl;//领证人证件种类
    private String lzrzjh;//领证人证件号
    private String lzrlxdh;//领证人联系电话
    private String sfhcdzzz;//是否合成电子证照

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }

    public String getSqid() {
        return sqid;
    }

    public void setSqid(String sqid) {
        this.sqid = sqid;
    }

    public String getWwslbh() {
        return wwslbh;
    }

    public void setWwslbh(String wwslbh) {
        this.wwslbh = wwslbh;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjlxmc() {
        return djlxmc;
    }

    public void setDjlxmc(String djlxmc) {
        this.djlxmc = djlxmc;
    }

    public String getSqdjlx() {
        return sqdjlx;
    }

    public void setSqdjlx(String sqdjlx) {
        this.sqdjlx = sqdjlx;
    }

    public String getSqdjlxmc() {
        return sqdjlxmc;
    }

    public void setSqdjlxmc(String sqdjlxmc) {
        this.sqdjlxmc = sqdjlxmc;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQllxmc() {
        return qllxmc;
    }

    public void setQllxmc(String qllxmc) {
        this.qllxmc = qllxmc;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getGyfsmc() {
        return gyfsmc;
    }

    public void setGyfsmc(String gyfsmc) {
        this.gyfsmc = gyfsmc;
    }

    public String getSffbcz() {
        return sffbcz;
    }

    public void setSffbcz(String sffbcz) {
        this.sffbcz = sffbcz;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYbdcqzh() {
        return ybdcqzh;
    }

    public void setYbdcqzh(String ybdcqzh) {
        this.ybdcqzh = ybdcqzh;
    }

    public String getYfczh() {
        return yfczh;
    }

    public void setYfczh(String yfczh) {
        this.yfczh = yfczh;
    }

    public String getYtdzh() {
        return ytdzh;
    }

    public void setYtdzh(String ytdzh) {
        this.ytdzh = ytdzh;
    }

    public String getYbdcywh() {
        return ybdcywh;
    }

    public void setYbdcywh(String ybdcywh) {
        this.ybdcywh = ybdcywh;
    }

    public String getYfcywh() {
        return yfcywh;
    }

    public void setYfcywh(String yfcywh) {
        this.yfcywh = yfcywh;
    }

    public String getYtdywh() {
        return ytdywh;
    }

    public void setYtdywh(String ytdywh) {
        this.ytdywh = ytdywh;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public Double getZgzqqdse() {
        return zgzqqdse;
    }

    public void setZgzqqdse(Double zgzqqdse) {
        this.zgzqqdse = zgzqqdse;
    }

    public Date getZwlxqxksrq() {
        return zwlxqxksrq;
    }

    public void setZwlxqxksrq(Date zwlxqxksrq) {
        this.zwlxqxksrq = zwlxqxksrq;
    }

    public Date getZwlxqxjsrq() {
        return zwlxqxjsrq;
    }

    public void setZwlxqxjsrq(Date zwlxqxjsrq) {
        this.zwlxqxjsrq = zwlxqxjsrq;
    }

    public Double getPgjz() {
        return pgjz;
    }

    public void setPgjz(Double pgjz) {
        this.pgjz = pgjz;
    }

    public String getDyfw() {
        return dyfw;
    }

    public void setDyfw(String dyfw) {
        this.dyfw = dyfw;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getDysw() {
        return dysw;
    }

    public void setDysw(String dysw) {
        this.dysw = dysw;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public String getSfaj() {
        return sfaj;
    }

    public void setSfaj(String sfaj) {
        this.sfaj = sfaj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getCjyh() {
        return cjyh;
    }

    public void setCjyh(String cjyh) {
        this.cjyh = cjyh;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public String getZdzhyt() {
        return zdzhyt;
    }

    public void setZdzhyt(String zdzhyt) {
        this.zdzhyt = zdzhyt;
    }

    public Integer getFwlx() {
        return fwlx;
    }

    public void setFwlx(Integer fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public String getSzmyc() {
        return szmyc;
    }

    public void setSzmyc(String szmyc) {
        this.szmyc = szmyc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Date getTdsyksqx() {
        return tdsyksqx;
    }

    public void setTdsyksqx(Date tdsyksqx) {
        this.tdsyksqx = tdsyksqx;
    }

    public Date getTdsyjsqx() {
        return tdsyjsqx;
    }

    public void setTdsyjsqx(Date tdsyjsqx) {
        this.tdsyjsqx = tdsyjsqx;
    }

    public String getZdzhqlxz() {
        return zdzhqlxz;
    }

    public void setZdzhqlxz(String zdzhqlxz) {
        this.zdzhqlxz = zdzhqlxz;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public Double getFdcjyjg() {
        return fdcjyjg;
    }

    public void setFdcjyjg(Double fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getLzr() {
        return lzr;
    }

    public void setLzr(String lzr) {
        this.lzr = lzr;
    }

    public String getLzrzjzl() {
        return lzrzjzl;
    }

    public void setLzrzjzl(String lzrzjzl) {
        this.lzrzjzl = lzrzjzl;
    }

    public String getLzrzjh() {
        return lzrzjh;
    }

    public void setLzrzjh(String lzrzjh) {
        this.lzrzjh = lzrzjh;
    }

    public String getLzrlxdh() {
        return lzrlxdh;
    }

    public void setLzrlxdh(String lzrlxdh) {
        this.lzrlxdh = lzrlxdh;
    }
}
